@@ -117,6 +117,7 @@ class LibraryContext:
         :param use_robocloud_vault: use json stored into `Robocloud Vault`
         """
         service = None
+        credentials = None
         self.logger.debug("Init service with scopes: %s", scopes)
         scopes = [f"https://www.googleapis.com/auth/{scope}" for scope in scopes]
         if use_robocorp_vault is not None:
@@ -183,7 +184,7 @@ class LibraryContext:
 
         cloud_auth_type = auth_type or self.ctx.cloud_auth_type
         if robocloud:
-            self.get_service_from_robocorp_vault(
+            service = self.get_service_from_robocorp_vault(
                 client_object, cloud_auth_type, service_account_file
             )
         elif service_account_file:
@@ -205,6 +206,9 @@ class LibraryContext:
             self.logger.info("Authenticating with default client object")
             service = client_object()
 
+        if service is None:
+            raise AssertionError("Failed to create service")
+
         return service
 
     def write_json(self, json_file, response):
